@@ -127,6 +127,14 @@ class Router(object):
 
         .. note:: The final views list is generated by the
                   :py:meth:`generate_views` method.
+
+    .. py:attribute:: fields
+
+        Fields that views should use by default.
+
+    .. py:attribute:: json_fields
+
+        Fields that the Router serializer should use by default.
     """
     views = ViewsDescriptor(
         getattr(settings, 'CRUDFLAP_VIEWS', CRUDLFAP_VIEWS)
@@ -395,3 +403,29 @@ class Router(object):
 
             result['properties'][field.name] = field_def
         return result
+
+    def get_json_fields(self):
+        return [
+            f.name for f in self.model._meta.fields
+        ]
+
+    def get_FIELD_json(self, obj, field):
+        value = getattr(obj, field)
+        if callable(value):
+            value = value()
+        if type(value) in self.registry:
+            value = self.registry[type(value)].serialize(value)
+        elif value and not isinstance(value, (str, int, float, bool)):
+            value = str(value)
+        return value
+
+    def serialize(self, obj, fields=None):
+        fields = fields or self.json_fields
+        return {
+            field: getattr(
+                self,
+                f'get_{field}_json',
+                self.get_FIELD_json,
+            )(obj, field)
+            for field in self.json_fields
+        }
